## Release Notes for 1.3

Released on 2 May 2021

The main feature of the 1.3 release is internationalisation. The release introduces support for Portuguese, French, and Norwegian for the main GUI, in addition to the default English. The settings for choosing the GUI language can be found in the main Preferences.

The implementation is such that the projects themselves can use a different language than the one selected for the GUI. To allow for better support for multiple language projects, the Build Novel Project tool has the added option to select the language of the injected text into exported documents. In particularly for the number words that can be added for chapter headers. Available languages here are the same as mentioned above for the main GUI, plus German.

Settings have also been added in Preferences to allow for automatic injection of spaces or non-breaking spaces in front of, or behind, certain characters. These are features generally available in text editors for French, but the implementation in novelWriter simply makes them a free text box where you can list all characters or symbols where you want a space added automatically.

The translation files for this release have been provided by Bruno Meneguello for the Portuguese translation, by Jan Lüdke (jyhelle) for the French translation, by Veronica Berglyd Olsen for the Norwegian translation as well as the minor modifications for US English, and Marian Lückhof provided the translation file for chapter numbers in German.

The work to rewrite novelWriter to allow for internationalisation was done by Bruno Meneguello and Veronica Berglyd Olsen.

See also the Releases page.